package com.sc.zuul;
import com.netflix.zuul.ZuulFilter;
import com.netflix.zuul.context.RequestContext;
import com.netflix.zuul.exception.ZuulException;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import javax.servlet.http.HttpServletRequest;

//@Component
public class AccessFilter extends ZuulFilter {

    //获取Zuul服务端口号
    @Value("${server.port}")
    private String serverPort;

    @Override
    public String filterType() {
        return "pre";
    }

    /**
     * 判断过滤器是否执行,直接返回true,代表对所有请求过滤
     * 此方法指定过滤范围
     * @return
     */
    @Override
    public int filterOrder() {
        return 0;
    }

    /**
     * 过滤的具体逻辑
     * @return
     */
    @Override
    public boolean shouldFilter() {
        return true;
    }

    @Override
    public Object run() throws ZuulException {
        RequestContext currentContext = RequestContext.getCurrentContext();
        HttpServletRequest request = currentContext.getRequest();
        String token = request.getParameter("token");
        request.setAttribute("serverPort", serverPort);
        if (StringUtils.isEmpty(token)) {
            currentContext.setSendZuulResponse(false);
            currentContext.setResponseBody("token is null");
            currentContext.setResponseStatusCode(401);
            return null;
        }
        System.out.println("网关执行端口号:" + serverPort);
        return null;
    }
}
